#
# spec file for package mysql-connector-cpp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libmysqlcppconn7
Name:           mysql-connector-cpp
Version:        1.1.9
Release:        lp150.2.5
Summary:        MySQL Connector/C++: Standardized database driver for C++ development
License:        SUSE-GPL-2.0-with-FLOSS-exception
Group:          Development/Libraries/C and C++
Url:            http://dev.mysql.com/downloads/connector/
Source:         http://dev.mysql.com/get/Downloads/Connector-C++/mysql-connector-c++-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE - mysql-connector-cpp-1.1.0-disable_tests_and_examples.patch adam@mizerski.pl -- disable building tests and examples
Patch2:         mysql-connector-cpp-1.1.0-disable_tests_and_examples.patch
# PATCH-FIX-UPSTREAM - bsc#1067883 kstreitova@suse.com -- fix build with libmariadb by fixing copypaste errors in libmysql_dynamic_proxy.cpp file
Patch3:         mysql-connector-cpp-1.1.9-libmysql_dynamic_proxy_typos.patch
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel >= 1.34.0
%endif
BuildRequires:  cmake >= 2.6.2
BuildRequires:  gcc-c++
BuildRequires:  libmysqlclient-devel
Obsoletes:      mysql-connector-c++ < %{version}
Provides:       mysql-connector-c++ = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
MySQL Connector/C++ is a MySQL database connector for C++ development. The
MySQL driver for C++ can be used to connect to MySQL from C++ applications. The
driver mimics the JDBC 4.0 API. It implements a significant subset of JDBC 4.0.

The Driver for C++ is designed to work best with MySQL 5.1 or later. Note - its
full functionality is not available when connecting to MySQL 5.0. You cannot
connect to MySQL 4.1 or earlier.

%package -n libmysqlcppconn-devel
Summary:        Development files for MySQL Connector/C++
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Obsoletes:      mysql-connector-c++-devel < %{version}
Provides:       mysql-connector-c++-devel = %{version}
%if 0%{?suse_version} > 1325
Requires:       libboost_headers-devel
%else
Requires:       boost-devel >= 1.34.0
%endif

%description -n libmysqlcppconn-devel
MySQL Connector/C++ is a MySQL database connector for C++ development. The
MySQL driver for C++ can be used to connect to MySQL from C++ applications. The
driver mimics the JDBC 4.0 API. It implements a significant subset of JDBC 4.0.

The Driver for C++ is designed to work best with MySQL 5.1 or later. Note - its
full functionality is not available when connecting to MySQL 5.0. You cannot
connect to MySQL 4.1 or earlier.

%package -n %{libname}
Summary:        MySQL Connector/C++: Standardized database driver for C++ development
Group:          Development/Libraries/C and C++

%description -n %{libname}
MySQL Connector/C++ is a MySQL database connector for C++ development. The
MySQL driver for C++ can be used to connect to MySQL from C++ applications. The
driver mimics the JDBC 4.0 API. It implements a significant subset of JDBC 4.0.

The Driver for C++ is designed to work best with MySQL 5.1 or later. Note - its
full functionality is not available when connecting to MySQL 5.0. You cannot
connect to MySQL 4.1 or earlier.

%prep
%setup -q -n mysql-connector-c++-%{version}
%patch2 -p1
%patch3 -p1
chmod -x examples/*

%build
%cmake \
	-DMYSQLCPPCONN_GCOV_ENABLE=OFF \
	-DMYSQLCPPCONN_ICU_ENABLE=OFF \
	-DMYSQLCPPCONN_BUILD_EXAMPLES=OFF \
	-DCMAKE_INSTALL_LIB_DIR=%{_lib} \
	-DMYSQLCLIENT_STATIC_BINDING=0 \
	-DMYSQL_CXX_LINKAGE=0
make %{?_smp_mflags} VERBOSE=1

%install
%cmake_install
rm -f %{buildroot}%{_libdir}/libmysqlcppconn-static.a
rm -f %{buildroot}%{_prefix}/[A-Z]*

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n libmysqlcppconn-devel
%defattr(-,root,root)
%doc README COPYING examples
%{_includedir}/*
%{_libdir}/*.so

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/*.so.*

%changelog
* Fri Nov 24 2017 kstreitova@suse.com
- add mysql-connector-cpp-1.1.9-libmysql_dynamic_proxy_typos.patch
  to fix build by fixing copypaste errors in
  libmysql_dynamic_proxy.cpp file [bsc#1067883]
- remove mariadb_api.patch that it's no longer needed because:
  * our current client library already provides mysql_get_option()
  * using MARIADB_BASE_VERSION is no longer working as intended as
    it's not defined in mariadb client library provided by
    mariadb-connector-c
  * hunk for stmt_free_result() was moved to
    mysql-connector-cpp-1.1.9-libmysql_dynamic_proxy_typos.patch
* Tue Sep  5 2017 kstreitova@suse.com
- Update to version 1.1.9:
  * release notes:
    https://dev.mysql.com/doc/relnotes/connector-cpp/en/news-1-1-9.html
- Remove installing of ANNOUNCEMENT and CHANGES files that are no
  longer present
- Add "Requires: libboost_headers-devel" for libmysqlcppconn-devel
  subpackage ("Requires: boost-devel" for the older distros that
  don't have libboost_headers-devel available yet) [bsc#838038]
* Wed May 31 2017 mpluskal@suse.com
- Update to version 1.1.8:
  * See the news files on
    https://dev.mysql.com/doc/relnotes/connector-cpp/en/
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Wed Aug 12 2015 tchvatal@suse.com
- Version bump to 1.1.6:
  * See the news files on
    https://dev.mysql.com/doc/relnotes/connector-cpp/en/
- Update soname to libmyslqcppcon7
- Remove needlessly long description
- Drop unneeded/merged patches:
  mysql-connector-cpp-1.1.0-cmake-paths-fix.patch
  mysql-connector-cpp-1.1.0-gcc44.patch
- Refresh patch:
  mysql-connector-cpp-1.1.0-disable_tests_and_examples.patch
- Add patch to build with mariadb:
  mariadb_api.patch
* Fri Aug 29 2014 tchvatal@suse.com
- Use cmake macros for building properly.
* Sat Jul 26 2014 cobexer@gmail.com
- disable gcov coverage recording
  Gcov is a development tool, it slows down execution and creates
  coverage data that is not useful to users of this library.
* Fri Apr 19 2013 mhrusecky@suse.cz
- Do not use macro for make install as it doesn't work on SLE
* Wed Apr 17 2013 mhrusecky@suse.cz
- Compatibility Obsoletes/Provides
* Wed Apr  3 2013 mhrusecky@suse.com
- Merge with package by Tomas Chvatal (to make it work with LO)
* Fri Mar  8 2013 saschpe@suse.de
- Fix library requirement for devel package due to wrong soversion
* Wed Feb 13 2013 adam@mizerski.pl
- update to 1.1.2, see
  https://dev.mysql.com/doc/relnotes/connector-cpp/en/ccpp-news-1-1-1.html
  https://dev.mysql.com/doc/relnotes/connector-cpp/en/ccpp-news-1-1-2.html
- libmysqlcppconn5 changed to libmysqlcppconn6 (number bump)
- spec file cleanup
- removed patch for driver/mysql_art_resultset.cpp from
  mysql-connector-cpp-1.1.0-gcc44.patch
- added mysql-connector-cpp-1.1.0-disable_tests_and_examples.patch
* Wed Jan 18 2012 cdenicolo@suse.com
- license update: SUSE-GPL-2.0-with-FLOSS-exception
  GPL has FLOSS exception.
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Thu Jun  2 2011 mhrusecky@suse.cz
- updated to version 1.1.0, see
  http://forge.mysql.com/wiki/Connector_C%%2B%%2B#MySQL_Connector.2FC.2B.2B_1.1.0_GA_.2813.09.2010.29
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Jul 28 2009 mhrusecky@suse.cz
- Better description (bnc#522682)
* Thu May 21 2009 mhrusecky@suse.cz
- updated to version 1.0.5
  * Changed the interface of sql::ConnectionMetaData, sql::ResultSetMetaData
    and sql::ParameterMetaData to have a protected destructor. In this way the
    client code doesn't need, and won't be able, to destruct the metadata
    objects returned by the connector. The connector will handle their
    destruction.  This enables statements like :
    connection->getMetaData->getSchema(); without the result of leaking memory
    because we lost the pointer returned by getMetaData().  (Lawrin, Andrey)
  * Large overhaul of the code to improve the memory management to not leak in
    exceptional situations. Big improvement compared to Beta1. (Andrey)
  * Fixed the interface of sql::Driver and sql::Connection so they accept the
    options map by alias instead of by value. (Andrey)
  * Changed the return type of sql::SQLException::getSQLState() from
    std::string to const char * to be consistent with std::exception::what().
    (Andrey)
  * Implemented getResultSetType() and setResultSetType() for Statement. Used
    are TYPE_FORWARD_ONLY, which means unbuffered result set and
    TYPE_SCROLL_INSENSITIVE, which means buffered result set. (Andrey)
  * Implemented getResultSetType() for PreparedStatement. The setter is not
    implemented because currently PreparedStatement can't do refetching and
    storing the result means the bind buffers will be correct. (Andrey)
  * Added "defaultStatementResultType" to MySQL_Connection::setClientOption()
    as an option. Also the method now returns `sql::Connection *`. (Andrey)
  * Added Result::getType() and implemented it in the three result set classes.
    (Andrey)
  * Enabled tracing functionality when building with VC8 and up (VS2005 and
    up). (Andrey)
  * Added better support for named pipes, on Windows. Use pipe:// and add the
    path to the pipe. Shared memory connections are currently not supported.
    (Andrey)
  * Fixed a bug in MySQL_Connection::setSessionVariable() which led to
    exception being thrown. (Andrey)
* Mon May 18 2009 mhrusecky@suse.cz
- fixed compilation using gcc44
* Fri Apr 17 2009 mhrusecky@suse.cz
- initial version of MySQL Connector/C++ package (version 1.0.4 beta)
